@@ -4,13 +4,19 @@
 # also regenerates all aclocal.m4, config.h.in, Makefile.in, configure files
 # with new versions of autoconf or automake.
 #
-# This script requires autoconf-2.60..2.61 and automake-1.10 in the PATH.
+# This script requires autoconf-2.60..2.65 and automake-1.11.1 in the PATH.
 # It also requires either
 #   - the GNULIB_TOOL environment variable pointing to the gnulib-tool script
 #     in a gnulib checkout, or
-#   - the cvs program in the PATH and an internet connection.
+#   - the git program in the PATH and an internet connection.
+# It also requires
+#   - the bison program,
+#   - the gperf program,
+#   - the groff program,
+#   - the makeinfo program from the texinfo package,
+#   - perl.
 
-# Copyright (C) 2003-2007 Free Software Foundation, Inc.
+# Copyright (C) 2003-2010 Free Software Foundation, Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,11 +33,11 @@
 
 # Usage: ./autogen.sh [--quick] [--skip-gnulib]
 #
-# Usage after a first-time CVS checkout:     ./autogen.sh
-# Usage after a CVS update:                  ./autogen.sh --quick
+# Usage after a first-time git clone / cvs checkout:   ./autogen.sh
+# Usage after a git clone / cvs update:                ./autogen.sh --quick
 # This uses an up-to-date gnulib checkout.
-# (The gettext-0.17 release was prepared using gnulib commit
-# bf5ebbca03613397b66521e98dd4ce28741c4689 from 2007-11-07.)
+# (The gettext-0.18.1 release was prepared using gnulib commit
+# 74d509383fe30bb5511a978b52e4f8ecae37826b from 2010-06-03.)
 #
 # Usage from a released tarball:             ./autogen.sh --quick --skip-gnulib
 # This does not use a gnulib checkout.
@@ -46,15 +52,16 @@ while :; do
   esac
 done
 
-if test $skip_gnulib = false; then
+# The tests in gettext-tools/tests are not meant to be executable, because
+# they have a TESTS_ENVIRONMENT that specifies the shell explicitly.
+
+if ! $skip_gnulib; then
   if test -z "$GNULIB_TOOL"; then
     # Check out gnulib in a subdirectory 'gnulib'.
-    GNULIB_CVS_ROOT=':pserver:anonymous@pserver.git.sv.gnu.org:/gnulib.git'
-    GNULIB_CVS_REPOSITORY='gnulib'
     if test -d gnulib; then
-      (cd gnulib && cvs update -d -P)
+      (cd gnulib && git pull)
     else
-      cvs -d "$GNULIB_CVS_ROOT" checkout -d $GNULIB_CVS_REPOSITORY HEAD
+      git clone git://git.savannah.gnu.org/gnulib.git
     fi
     # Now it should contain a gnulib-tool.
     if test -f gnulib/gnulib-tool; then
@@ -74,14 +81,17 @@ if test $skip_gnulib = false; then
       basename
       closeout
       error
-      exit
-      getopt
+      getopt-gnu
       gettext-h
+      havelib
       memmove
       progname
       propername
       relocatable-prog
+      sigpipe
       stdbool
+      stdio
+      stdlib
       strtoul
       unlocked-io
       xalloc
@@ -94,6 +104,18 @@ if test $skip_gnulib = false; then
     '
     $GNULIB_TOOL --dir=gettext-runtime --lib=libgrt --source-base=gnulib-lib --m4-base=gnulib-m4 --no-libtool --local-dir=gnulib-local --local-symlink \
       --import $GNULIB_MODULES_RUNTIME_FOR_SRC $GNULIB_MODULES_RUNTIME_OTHER
+    # In gettext-runtime/libasprintf:
+    if test -f gettext-runtime/libasprintf/gnulib-m4/gnulib-cache.m4; then
+      mv -f gettext-runtime/libasprintf/gnulib-m4/gnulib-cache.m4 gettext-runtime/libasprintf/gnulib-m4/gnulib-cache.m4~
+    fi
+    GNULIB_MODULES_LIBASPRINTF='
+      alloca
+      errno
+    '
+    GNULIB_MODULES_LIBASPRINTF_OTHER='
+    '
+    $GNULIB_TOOL --dir=gettext-runtime/libasprintf --source-base=. --m4-base=gnulib-m4 --lgpl=2 --makefile-name=Makefile.gnulib --libtool --local-dir=gnulib-local --local-symlink \
+      --import $GNULIB_MODULES_LIBASPRINTF $GNULIB_MODULES_LIBASPRINTF_OTHER
     # In gettext-tools:
     if test -f gettext-tools/gnulib-m4/gnulib-cache.m4; then
       mv -f gettext-tools/gnulib-m4/gnulib-cache.m4 gettext-tools/gnulib-m4/gnulib-cache.m4~
@@ -118,26 +140,25 @@ if test $skip_gnulib = false; then
       error
       error-progname
       execute
-      exit
       fd-ostream
       file-ostream
       filename
       findprog
-      fnmatch-posix
+      fnmatch
       fopen
       fstrcmp
       full-write
       fwriteerror
       gcd
       getline
-      getopt
+      getopt-gnu
       gettext-h
       hash
       html-styled-ostream
       iconv
       javacomp
       javaexec
-      linebreak
+      libunistring-optional
       localcharset
       locale
       localename
@@ -150,57 +171,95 @@ if test $skip_gnulib = false; then
       openmp
       ostream
       pipe
+      pipe-filter-ii
       progname
       propername
       relocatable-prog
       relocatable-script
       sh-quote
+      sigpipe
+      sigprocmask
       stdbool
+      stdio
+      stdlib
       stpcpy
       stpncpy
       strcspn
+      strerror
       strpbrk
       strtol
       strtoul
       styled-ostream
+      sys_select
       sys_stat
       sys_time
       term-styled-ostream
-      ucs4-utf8
+      unilbrk/ulc-width-linebreaks
       uniname/uniname
       unistd
+      unistr/u8-mbtouc
+      unistr/u8-uctomb
+      unistr/u16-mbtouc
       uniwidth/width
       unlocked-io
-      utf8-ucs4
-      utf16-ucs4
       vasprintf
       wait-process
+      write
       xalloc
+      xconcat-filename
       xmalloca
       xerror
       xsetenv
       xstriconv
+      xstriconveh
       xvasprintf
     '
-    # Not yet used. Add some files to gettext-tools-misc instead.
-    GNULIB_MODULES_TOOLS_FOR_LIBGREP='
-      error
-      exitfail
+    # Common dependencies of GNULIB_MODULES_TOOLS_FOR_SRC and GNULIB_MODULES_TOOLS_FOR_LIBGREP.
+    GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES='
+      alloca-opt
+      arg-nonnull
+      c++defs
+      extensions
       gettext-h
-      hard-locale
-      obstack
-      regex
+      include_next
+      localcharset
+      malloc-posix
+      mbrtowc
+      mbsinit
+      multiarch
+      ssize_t
       stdbool
-      xalloc
+      stddef
+      stdint
+      stdlib
+      streq
+      unistd
+      verify
+      warn-on-use
+      wchar
+      wctype
     '
     GNULIB_MODULES_TOOLS_OTHER='
       gettext-tools-misc
+      csharpcomp-script
+      csharpexec-script
       gcj
       java
+      javacomp-script
+      javaexec-script
       stdint
     '
     $GNULIB_TOOL --dir=gettext-tools --lib=libgettextlib --source-base=gnulib-lib --m4-base=gnulib-m4 --tests-base=gnulib-tests --makefile-name=Makefile.gnulib --libtool --with-tests --local-dir=gnulib-local --local-symlink \
-      --import $GNULIB_MODULES_TOOLS_FOR_SRC $GNULIB_MODULES_TOOLS_OTHER
+      --import --avoid=hash-tests $GNULIB_MODULES_TOOLS_FOR_SRC $GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES $GNULIB_MODULES_TOOLS_OTHER
+    # In gettext-tools/libgrep:
+    if test -f gettext-tools/libgrep/gnulib-m4/gnulib-cache.m4; then
+      mv -f gettext-tools/libgrep/gnulib-m4/gnulib-cache.m4 gettext-tools/libgrep/gnulib-m4/gnulib-cache.m4~
+    fi
+    GNULIB_MODULES_TOOLS_FOR_LIBGREP='
+      regex
+    '
+    $GNULIB_TOOL --dir=gettext-tools --macro-prefix=grgl --lib=libgrep --source-base=libgrep --m4-base=libgrep/gnulib-m4 --makefile-name=Makefile.gnulib --local-dir=gnulib-local --local-symlink \
+      --import `for m in $GNULIB_MODULES_TOOLS_FOR_SRC_COMMON_DEPENDENCIES; do if test \`$GNULIB_TOOL --extract-applicability $m\` != all; then echo --avoid=$m; fi; done` $GNULIB_MODULES_TOOLS_FOR_LIBGREP
     # In gettext-tools/libgettextpo:
     if test -f gettext-tools/libgettextpo/gnulib-m4/gnulib-cache.m4; then
       mv -f gettext-tools/libgettextpo/gnulib-m4/gnulib-cache.m4 gettext-tools/libgettextpo/gnulib-m4/gnulib-cache.m4~
@@ -213,7 +272,6 @@ if test $skip_gnulib = false; then
       c-strstr
       error
       error-progname
-      exit
       file-ostream
       filename
       fopen
@@ -224,19 +282,26 @@ if test $skip_gnulib = false; then
       gettext-h
       hash
       iconv
-      linebreak
+      libunistring-optional
       minmax
+      open
       ostream
       progname
       relocatable-lib
+      sigpipe
       stdbool
-      ucs4-utf8
+      stdio
+      stdlib
+      strerror
+      unilbrk/ulc-width-linebreaks
+      unistr/u8-mbtouc
+      unistr/u8-uctomb
+      unistr/u16-mbtouc
       uniwidth/width
       unlocked-io
-      utf8-ucs4
-      utf16-ucs4
       vasprintf
       xalloc
+      xconcat-filename
       xmalloca
       xerror
       xstriconv
@@ -249,47 +314,71 @@ if test $skip_gnulib = false; then
   fi
 fi
 
-(cd autoconf-lib-link
- ../build-aux/fixaclocal aclocal -I m4 -I ../m4
+# Fetch config.guess, config.sub.
+if test -n "$GNULIB_TOOL"; then
+  for file in config.guess config.sub; do
+    $GNULIB_TOOL --copy-file build-aux/$file; chmod a+x build-aux/$file
+  done
+else
+  for file in config.guess config.sub; do
+    wget -q --timeout=5 -O build-aux/$file.tmp "http://git.savannah.gnu.org/gitweb/?p=gnulib.git;a=blob_plain;f=build-aux/${file};hb=HEAD" \
+      && mv build-aux/$file.tmp build-aux/$file \
+      && chmod a+x build-aux/$file
+  done
+fi
+
+(cd gettext-runtime/libasprintf
+ ../../build-aux/fixaclocal aclocal -I ../../m4 -I ../m4 -I gnulib-m4
  autoconf
- automake
+ autoheader && touch config.h.in
+ automake --add-missing --copy
 )
 
 (cd gettext-runtime
- ../build-aux/fixaclocal aclocal -I m4 -I ../autoconf-lib-link/m4 -I ../m4 -I gnulib-m4
+ ../build-aux/fixaclocal aclocal -I m4 -I ../m4 -I gnulib-m4
  autoconf
  autoheader && touch config.h.in
- automake
-)
-
-(cd gettext-runtime/libasprintf
- ../../build-aux/fixaclocal aclocal -I ../../m4 -I ../m4
- autoconf
- autoheader && touch config.h.in
- automake
+ automake --add-missing --copy
+ # Rebuilding the PO files and manual pages is only rarely needed.
+ if ! $quick; then
+   ./configure --disable-java --disable-native-java --disable-csharp \
+     && (cd po && make update-po) \
+     && (cd intl && make) && (cd gnulib-lib && make) && (cd src && make) \
+     && (cd man && make update-man1 all) \
+     && make distclean
+ fi
 )
 
 cp -p gettext-runtime/ABOUT-NLS gettext-tools/ABOUT-NLS
 
-(cd gettext-tools
- ../build-aux/fixaclocal aclocal -I m4 -I ../gettext-runtime/m4 -I ../autoconf-lib-link/m4 -I ../m4 -I gnulib-m4 -I libgettextpo/gnulib-m4
- autoconf
- autoheader && touch config.h.in
- automake
-)
-
 (cd gettext-tools/examples
  ../../build-aux/fixaclocal aclocal -I ../../gettext-runtime/m4 -I ../../m4
  autoconf
- automake
+ automake --add-missing --copy
  # Rebuilding the examples PO files is only rarely needed.
  if ! $quick; then
    ./configure && (cd po && make update-po) && make distclean
  fi
 )
 
-build-aux/fixaclocal aclocal
+(cd gettext-tools
+ ../build-aux/fixaclocal aclocal -I m4 -I ../gettext-runtime/m4 -I ../m4 -I gnulib-m4 -I libgrep/gnulib-m4 -I libgettextpo/gnulib-m4
+ autoconf
+ autoheader && touch config.h.in
+ test -d intl || mkdir intl
+ automake --add-missing --copy
+ # Rebuilding the PO files, manual pages, documentation, test files is only rarely needed.
+ if ! $quick; then
+   ./configure --disable-java --disable-native-java --disable-csharp --disable-openmp \
+     && (cd po && make update-po) \
+     && (cd intl && make) && (cd gnulib-lib && make) && (cd libgrep && make) && (cd src && make) \
+     && (cd man && make update-man1 all) \
+     && (cd doc && make all) \
+     && (cd tests && make update-expected) \
+     && make distclean
+ fi
+)
+
+build-aux/fixaclocal aclocal -I m4
 autoconf
 automake
-
-cp -p autoconf-lib-link/config.rpath build-aux/config.rpath
