@@ -1,5 +1,5 @@
 /* xgettext Tcl backend.
-   Copyright (C) 2002-2003, 2005-2007 Free Software Foundation, Inc.
+   Copyright (C) 2002-2003, 2005-2009 Free Software Foundation, Inc.
 
    This file was written by Bruno Haible <haible@clisp.cons.org>, 2002.
 
@@ -33,7 +33,6 @@
 
 #include "message.h"
 #include "xgettext.h"
-#include "x-tcl.h"
 #include "error.h"
 #include "xalloc.h"
 #include "hash.h"
@@ -91,14 +90,14 @@ x_tcl_keyword (const char *name)
       struct callshape shape;
 
       if (keywords.table == NULL)
-	hash_init (&keywords, 100);
+        hash_init (&keywords, 100);
 
       split_keywordspec (name, &end, &shape);
 
       /* The characters between name and end should form a valid Tcl
-	 function name.  A leading "::" is redundant.  */
+         function name.  A leading "::" is redundant.  */
       if (end - name >= 2 && name[0] == ':' && name[1] == ':')
-	name += 2;
+        name += 2;
 
       insert_keyword_callshape (&keywords, name, end - name, &shape);
     }
@@ -112,7 +111,7 @@ init_keywords ()
   if (default_keywords)
     {
       /* When adding new keywords here, also update the documentation in
-	 xgettext.texi!  */
+         xgettext.texi!  */
       x_tcl_keyword ("::msgcat::mc");
       default_keywords = false;
     }
@@ -148,7 +147,7 @@ do_getc ()
   if (c == EOF)
     {
       if (ferror (fp))
-	error (EXIT_FAILURE, errno, _("\
+        error (EXIT_FAILURE, errno, _("\
 error while reading \"%s\""), real_file_name);
     }
   else if (c == '\n')
@@ -185,7 +184,7 @@ phase1_getc ()
     {
       c = phase1_pushback[--phase1_pushback_length];
       if (c == '\n' || c == BS_NL)
-	++line_number;
+        ++line_number;
       return c;
     }
   c = do_getc ();
@@ -195,14 +194,14 @@ phase1_getc ()
   if (c != '\n')
     {
       if (c != EOF)
-	do_ungetc (c);
+        do_ungetc (c);
       return '\\';
     }
   for (;;)
     {
       c = do_getc ();
       if (!(c == ' ' || c == '\t'))
-	break;
+        break;
     }
   if (c != EOF)
     do_ungetc (c);
@@ -225,7 +224,7 @@ phase1_ungetc (int c)
 
     default:
       if (phase1_pushback_length == SIZEOF (phase1_pushback))
-	abort ();
+        abort ();
       phase1_pushback[phase1_pushback_length++] = c;
       break;
     }
@@ -271,11 +270,11 @@ phase2_getc ()
     {
       c = phase2_pushback[--phase2_pushback_length];
       if (c == '\n' || c == BS_NL)
-	++line_number;
+        ++line_number;
       else if (c == '{')
-	++brace_depth;
+        ++brace_depth;
       else if (c == '}')
-	--brace_depth;
+        --brace_depth;
       return c;
     }
   c = phase1_getc ();
@@ -284,7 +283,7 @@ phase2_getc ()
   else if (c == '}')
     {
       if (--brace_depth == 0)
-	c = CL_BRACE;
+        c = CL_BRACE;
     }
   return c;
 }
@@ -296,22 +295,22 @@ phase2_ungetc (int c)
   if (c != EOF)
     {
       switch (c)
-	{
-	case '\n':
-	case BS_NL:
-	  --line_number;
-	  break;
+        {
+        case '\n':
+        case BS_NL:
+          --line_number;
+          break;
 
-	case '{':
-	  --brace_depth;
-	  break;
+        case '{':
+          --brace_depth;
+          break;
 
-	case '}':
-	  ++brace_depth;
-	  break;
-	}
+        case '}':
+          ++brace_depth;
+          break;
+        }
       if (phase2_pushback_length == SIZEOF (phase2_pushback))
-	abort ();
+        abort ();
       phase2_pushback[phase2_pushback_length++] = c;
     }
 }
@@ -323,9 +322,9 @@ phase2_ungetc (int c)
 /* A token consists of a sequence of characters.  */
 struct token
 {
-  int allocated;		/* number of allocated 'token_char's */
-  int charcount;		/* number of used 'token_char's */
-  char *chars;			/* the token's constituents */
+  int allocated;                /* number of allocated 'token_char's */
+  int charcount;                /* number of used 'token_char's */
+  char *chars;                  /* the token's constituents */
 };
 
 /* Initialize a 'struct token'.  */
@@ -384,7 +383,7 @@ static inline void
 comment_line_end ()
 {
   while (buflen >= 1
-	 && (buffer[buflen - 1] == ' ' || buffer[buflen - 1] == '\t'))
+         && (buffer[buflen - 1] == ' ' || buffer[buflen - 1] == '\t'))
     --buflen;
   if (buflen >= bufmax)
     {
@@ -415,19 +414,19 @@ static message_list_ty *mlp;
    string literals).  Other words need not to be represented precisely.  */
 enum word_type
 {
-  t_string,	/* constant string */
-  t_other,	/* other string */
-  t_separator,	/* command separator: semicolon or newline */
-  t_bracket,	/* ']' pseudo word */
-  t_brace,	/* '}' pseudo word */
-  t_eof		/* EOF marker */
+  t_string,     /* constant string */
+  t_other,      /* other string */
+  t_separator,  /* command separator: semicolon or newline */
+  t_bracket,    /* ']' pseudo word */
+  t_brace,      /* '}' pseudo word */
+  t_eof         /* EOF marker */
 };
 
 struct word
 {
   enum word_type type;
-  struct token *token;		/* for t_string */
-  int line_number_at_start;	/* for t_string */
+  struct token *token;          /* for t_string */
+  int line_number_at_start;     /* for t_string */
 };
 
 /* Free the memory pointed to by a 'struct word'.  */
@@ -490,70 +489,70 @@ do_getc_escaped ()
       return '\v';
     case 'x':
       {
-	int n = 0;
-	unsigned int i;
+        int n = 0;
+        unsigned int i;
 
-	for (i = 0;; i++)
-	  {
-	    c = phase1_getc ();
-	    if (c == EOF || !c_isxdigit ((unsigned char) c))
-	      break;
+        for (i = 0;; i++)
+          {
+            c = phase1_getc ();
+            if (c == EOF || !c_isxdigit ((unsigned char) c))
+              break;
 
-	    if (c >= '0' && c <= '9')
-	      n = (n << 4) + (c - '0');
-	    else if (c >= 'A' && c <= 'F')
-	      n = (n << 4) + (c - 'A' + 10);
-	    else if (c >= 'a' && c <= 'f')
-	      n = (n << 4) + (c - 'a' + 10);
-	  }
-	phase1_ungetc (c);
-	return (i > 0 ? (unsigned char) n : 'x');
+            if (c >= '0' && c <= '9')
+              n = (n << 4) + (c - '0');
+            else if (c >= 'A' && c <= 'F')
+              n = (n << 4) + (c - 'A' + 10);
+            else if (c >= 'a' && c <= 'f')
+              n = (n << 4) + (c - 'a' + 10);
+          }
+        phase1_ungetc (c);
+        return (i > 0 ? (unsigned char) n : 'x');
       }
     case 'u':
       {
-	int n = 0;
-	unsigned int i;
+        int n = 0;
+        unsigned int i;
 
-	for (i = 0; i < 4; i++)
-	  {
-	    c = phase1_getc ();
-	    if (c == EOF || !c_isxdigit ((unsigned char) c))
-	      break;
+        for (i = 0; i < 4; i++)
+          {
+            c = phase1_getc ();
+            if (c == EOF || !c_isxdigit ((unsigned char) c))
+              break;
 
-	    if (c >= '0' && c <= '9')
-	      n = (n << 4) + (c - '0');
-	    else if (c >= 'A' && c <= 'F')
-	      n = (n << 4) + (c - 'A' + 10);
-	    else if (c >= 'a' && c <= 'f')
-	      n = (n << 4) + (c - 'a' + 10);
-	  }
-	phase1_ungetc (c);
-	return (i > 0 ? n : 'u');
+            if (c >= '0' && c <= '9')
+              n = (n << 4) + (c - '0');
+            else if (c >= 'A' && c <= 'F')
+              n = (n << 4) + (c - 'A' + 10);
+            else if (c >= 'a' && c <= 'f')
+              n = (n << 4) + (c - 'a' + 10);
+          }
+        phase1_ungetc (c);
+        return (i > 0 ? n : 'u');
       }
     case '0': case '1': case '2': case '3': case '4':
     case '5': case '6': case '7':
       {
-	int n = c - '0';
+        int n = c - '0';
 
-	c = phase1_getc ();
-	if (c != EOF)
-	  {
-	    if (c >= '0' && c <= '7')
-	      {
-		n = (n << 3) + (c - '0');
-		c = phase1_getc ();
-		if (c != EOF)
-		  {
-		    if (c >= '0' && c <= '7')
-		      n = (n << 3) + (c - '0');
-		    else
-		      phase1_ungetc (c);
-		  }
-	      }
-	    else
-	      phase1_ungetc (c);
-	  }
-	return (unsigned char) n;
+        c = phase1_getc ();
+        if (c != EOF)
+          {
+            if (c >= '0' && c <= '7')
+              {
+                n = (n << 3) + (c - '0');
+                c = phase1_getc ();
+                if (c != EOF)
+                  {
+                    if (c >= '0' && c <= '7')
+                      n = (n << 3) + (c - '0');
+                    else
+                      phase1_ungetc (c);
+                  }
+              }
+            else
+              phase1_ungetc (c);
+          }
+        return (unsigned char) n;
       }
     default:
       /* Note: If c is non-ASCII, Tcl's behaviour is undefined here.  */
@@ -564,22 +563,22 @@ do_getc_escaped ()
 
 enum terminator
 {
-  te_space_separator,		/* looking for space semicolon newline */
-  te_space_separator_bracket,	/* looking for space semicolon newline ']' */
-  te_paren,			/* looking for ')' */
-  te_quote			/* looking for '"' */
+  te_space_separator,           /* looking for space semicolon newline */
+  te_space_separator_bracket,   /* looking for space semicolon newline ']' */
+  te_paren,                     /* looking for ')' */
+  te_quote                      /* looking for '"' */
 };
 
 /* Forward declaration of local functions.  */
 static enum word_type read_command_list (int looking_for,
-					 flag_context_ty outer_context);
+                                         flag_context_ty outer_context);
 
 /* Accumulate tokens into the given word.
    'looking_for' denotes a parse terminator combination.
    Return the first character past the token.  */
 static int
 accumulate_word (struct word *wp, enum terminator looking_for,
-		 flag_context_ty context)
+                 flag_context_ty context)
 {
   int c;
 
@@ -588,123 +587,123 @@ accumulate_word (struct word *wp, enum terminator looking_for,
       c = phase2_getc ();
 
       if (c == EOF || c == CL_BRACE)
-	return c;
+        return c;
       if ((looking_for == te_space_separator
-	   || looking_for == te_space_separator_bracket)
-	  && (c == ' ' || c == BS_NL
-	      || c == '\t' || c == '\v' || c == '\f' || c == '\r'
-	      || c == ';' || c == '\n'))
-	return c;
+           || looking_for == te_space_separator_bracket)
+          && (c == ' ' || c == BS_NL
+              || c == '\t' || c == '\v' || c == '\f' || c == '\r'
+              || c == ';' || c == '\n'))
+        return c;
       if (looking_for == te_space_separator_bracket && c == ']')
-	return c;
+        return c;
       if (looking_for == te_paren && c == ')')
-	return c;
+        return c;
       if (looking_for == te_quote && c == '"')
-	return c;
+        return c;
 
       if (c == '$')
-	{
-	  /* Distinguish $varname, ${varname} and lone $.  */
-	  c = phase2_getc ();
-	  if (c == '{')
-	    {
-	      /* ${varname} */
-	      do
-		c = phase2_getc ();
-	      while (c != EOF && c != '}');
-	      wp->type = t_other;
-	    }
-	  else
-	    {
-	      bool nonempty = false;
+        {
+          /* Distinguish $varname, ${varname} and lone $.  */
+          c = phase2_getc ();
+          if (c == '{')
+            {
+              /* ${varname} */
+              do
+                c = phase2_getc ();
+              while (c != EOF && c != '}');
+              wp->type = t_other;
+            }
+          else
+            {
+              bool nonempty = false;
 
-	      for (; c != EOF && c != CL_BRACE; c = phase2_getc ())
-		{
-		  if (c_isalnum ((unsigned char) c) || (c == '_'))
-		    {
-		      nonempty = true;
-		      continue;
-		    }
-		  if (c == ':')
-		    {
-		      c = phase2_getc ();
-		      if (c == ':')
-			{
-			  do
-			    c = phase2_getc ();
-			  while (c == ':');
+              for (; c != EOF && c != CL_BRACE; c = phase2_getc ())
+                {
+                  if (c_isalnum ((unsigned char) c) || (c == '_'))
+                    {
+                      nonempty = true;
+                      continue;
+                    }
+                  if (c == ':')
+                    {
+                      c = phase2_getc ();
+                      if (c == ':')
+                        {
+                          do
+                            c = phase2_getc ();
+                          while (c == ':');
 
-			  phase2_ungetc (c);
-			  nonempty = true;
-			  continue;
-			}
-		      phase2_ungetc (c);
-		      c = ':';
-		    }
-		  break;
-		}
-	      if (c == '(')
-		{
-		  /* $varname(index) */
-		  struct word index_word;
+                          phase2_ungetc (c);
+                          nonempty = true;
+                          continue;
+                        }
+                      phase2_ungetc (c);
+                      c = ':';
+                    }
+                  break;
+                }
+              if (c == '(')
+                {
+                  /* $varname(index) */
+                  struct word index_word;
 
-		  index_word.type = t_other;
-		  c = accumulate_word (&index_word, te_paren, null_context);
-		  if (c != EOF && c != ')')
-		    phase2_ungetc (c);
-		  wp->type = t_other;
-		}
-	      else
-		{
-		  phase2_ungetc (c);
-		  if (nonempty)
-		    {
-		      /* $varname */
-		      wp->type = t_other;
-		    }
-		  else
-		    {
-		      /* lone $ */
-		      if (wp->type == t_string)
-			{
-			  grow_token (wp->token);
-			  wp->token->chars[wp->token->charcount++] = '$';
-			}
-		    }
-		}
-	    }
-	}
+                  index_word.type = t_other;
+                  c = accumulate_word (&index_word, te_paren, null_context);
+                  if (c != EOF && c != ')')
+                    phase2_ungetc (c);
+                  wp->type = t_other;
+                }
+              else
+                {
+                  phase2_ungetc (c);
+                  if (nonempty)
+                    {
+                      /* $varname */
+                      wp->type = t_other;
+                    }
+                  else
+                    {
+                      /* lone $ */
+                      if (wp->type == t_string)
+                        {
+                          grow_token (wp->token);
+                          wp->token->chars[wp->token->charcount++] = '$';
+                        }
+                    }
+                }
+            }
+        }
       else if (c == '[')
-	{
-	  read_command_list (']', context);
-	  wp->type = t_other;
-	}
+        {
+          read_command_list (']', context);
+          wp->type = t_other;
+        }
       else if (c == '\\')
-	{
-	  unsigned int uc;
-	  unsigned char utf8buf[6];
-	  int count;
-	  int i;
+        {
+          unsigned int uc;
+          unsigned char utf8buf[6];
+          int count;
+          int i;
 
-	  uc = do_getc_escaped ();
-	  assert (uc < 0x10000);
-	  count = u8_uctomb (utf8buf, uc, 6);
-	  assert (count > 0);
-	  if (wp->type == t_string)
-	    for (i = 0; i < count; i++)
-	      {
-		grow_token (wp->token);
-		wp->token->chars[wp->token->charcount++] = utf8buf[i];
-	      }
-	}
+          uc = do_getc_escaped ();
+          assert (uc < 0x10000);
+          count = u8_uctomb (utf8buf, uc, 6);
+          assert (count > 0);
+          if (wp->type == t_string)
+            for (i = 0; i < count; i++)
+              {
+                grow_token (wp->token);
+                wp->token->chars[wp->token->charcount++] = utf8buf[i];
+              }
+        }
       else
-	{
-	  if (wp->type == t_string)
-	    {
-	      grow_token (wp->token);
-	      wp->token->chars[wp->token->charcount++] = (unsigned char) c;
-	    }
-	}
+        {
+          if (wp->type == t_string)
+            {
+              grow_token (wp->token);
+              wp->token->chars[wp->token->charcount++] = (unsigned char) c;
+            }
+        }
     }
 }
 
@@ -719,7 +718,7 @@ read_word (struct word *wp, int looking_for, flag_context_ty context)
   do
     c = phase2_getc ();
   while (c == ' ' || c == BS_NL
-	 || c == '\t' || c == '\v' || c == '\f' || c == '\r');
+         || c == '\t' || c == '\v' || c == '\f' || c == '\r');
 
   if (c == EOF)
     {
@@ -737,9 +736,9 @@ read_word (struct word *wp, int looking_for, flag_context_ty context)
   if (c == '\n')
     {
       /* Comments assumed to be grouped with a message must immediately
-	 precede it, with no non-whitespace token on a line between both.  */
+         precede it, with no non-whitespace token on a line between both.  */
       if (last_non_comment_line > last_comment_line)
-	savable_comment_reset ();
+        savable_comment_reset ();
       wp->type = t_separator;
       return;
     }
@@ -764,14 +763,14 @@ read_word (struct word *wp, int looking_for, flag_context_ty context)
       enum word_type terminator;
 
       /* Start a new nested character group, which lasts until the next
-	 balanced '}' (ignoring \} things).  */
+         balanced '}' (ignoring \} things).  */
       previous_depth = phase2_push () - 1;
 
       /* Interpret it as a command list.  */
       terminator = read_command_list ('\0', null_context);
 
       if (terminator == t_brace)
-	phase2_pop (previous_depth);
+        phase2_pop (previous_depth);
 
       wp->type = t_other;
       last_non_comment_line = line_number;
@@ -787,18 +786,18 @@ read_word (struct word *wp, int looking_for, flag_context_ty context)
     {
       c = accumulate_word (wp, te_quote, context);
       if (c != EOF && c != '"')
-	phase2_ungetc (c);
+        phase2_ungetc (c);
     }
   else
     {
       phase2_ungetc (c);
       c = accumulate_word (wp,
-			   looking_for == ']'
-			   ? te_space_separator_bracket
-			   : te_space_separator,
-			   context);
+                           looking_for == ']'
+                           ? te_space_separator_bracket
+                           : te_space_separator,
+                           context);
       if (c != EOF)
-	phase2_ungetc (c);
+        phase2_ungetc (c);
     }
 
   if (wp->type != t_string)
@@ -825,119 +824,120 @@ read_command (int looking_for, flag_context_ty outer_context)
       c = phase2_getc ();
 
       if (c == ' ' || c == BS_NL
-	  || c == '\t' || c == '\v' || c == '\f' || c == '\r')
-	continue;
+          || c == '\t' || c == '\v' || c == '\f' || c == '\r')
+        continue;
       if (c == '#')
-	{
-	  /* Skip a comment up to end of line.  */
-	  last_comment_line = line_number;
-	  comment_start ();
-	  for (;;)
-	    {
-	      c = phase2_getc ();
-	      if (c == EOF || c == CL_BRACE || c == '\n')
-		break;
-	      /* We skip all leading white space, but not EOLs.  */
-	      if (!(buflen == 0 && (c == ' ' || c == '\t')))
-		comment_add (c);
-	    }
-	  comment_line_end ();
-	  continue;
-	}
+        {
+          /* Skip a comment up to end of line.  */
+          last_comment_line = line_number;
+          comment_start ();
+          for (;;)
+            {
+              c = phase2_getc ();
+              if (c == EOF || c == CL_BRACE || c == '\n')
+                break;
+              /* We skip all leading white space, but not EOLs.  */
+              if (!(buflen == 0 && (c == ' ' || c == '\t')))
+                comment_add (c);
+            }
+          comment_line_end ();
+          continue;
+        }
       break;
     }
   phase2_ungetc (c);
 
   /* Read the words that make up the command.  */
   {
-    int arg = 0;		/* Current argument number.  */
+    int arg = 0;                /* Current argument number.  */
     flag_context_list_iterator_ty context_iter;
     const struct callshapes *shapes = NULL;
     struct arglist_parser *argparser = NULL;
 
     for (;; arg++)
       {
-	struct word inner;
-	flag_context_ty inner_context;
+        struct word inner;
+        flag_context_ty inner_context;
 
-	if (arg == 0)
-	  inner_context = null_context;
-	else
-	  inner_context =
-	    inherited_context (outer_context,
-			       flag_context_list_iterator_advance (
-				 &context_iter));
+        if (arg == 0)
+          inner_context = null_context;
+        else
+          inner_context =
+            inherited_context (outer_context,
+                               flag_context_list_iterator_advance (
+                                 &context_iter));
 
-	read_word (&inner, looking_for, inner_context);
+        read_word (&inner, looking_for, inner_context);
 
-	/* Recognize end of command.  */
-	if (inner.type == t_separator || inner.type == t_bracket
-	    || inner.type == t_brace || inner.type == t_eof)
-	  {
-	    if (argparser != NULL)
-	      arglist_parser_done (argparser, arg);
-	    return inner.type;
-	  }
+        /* Recognize end of command.  */
+        if (inner.type == t_separator || inner.type == t_bracket
+            || inner.type == t_brace || inner.type == t_eof)
+          {
+            if (argparser != NULL)
+              arglist_parser_done (argparser, arg);
+            return inner.type;
+          }
 
-	if (extract_all)
-	  {
-	    if (inner.type == t_string)
-	      {
-		lex_pos_ty pos;
+        if (extract_all)
+          {
+            if (inner.type == t_string)
+              {
+                lex_pos_ty pos;
 
-		pos.file_name = logical_file_name;
-		pos.line_number = inner.line_number_at_start;
-		remember_a_message (mlp, NULL, string_of_word (&inner),
-				    inner_context, &pos, savable_comment);
-	      }
-	  }
+                pos.file_name = logical_file_name;
+                pos.line_number = inner.line_number_at_start;
+                remember_a_message (mlp, NULL, string_of_word (&inner),
+                                    inner_context, &pos,
+                                    NULL, savable_comment);
+              }
+          }
 
-	if (arg == 0)
-	  {
-	    /* This is the function position.  */
-	    if (inner.type == t_string)
-	      {
-		char *function_name = string_of_word (&inner);
-		char *stripped_name;
-		void *keyword_value;
+        if (arg == 0)
+          {
+            /* This is the function position.  */
+            if (inner.type == t_string)
+              {
+                char *function_name = string_of_word (&inner);
+                char *stripped_name;
+                void *keyword_value;
 
-		/* A leading "::" is redundant.  */
-		stripped_name = function_name;
-		if (function_name[0] == ':' && function_name[1] == ':')
-		  stripped_name += 2;
+                /* A leading "::" is redundant.  */
+                stripped_name = function_name;
+                if (function_name[0] == ':' && function_name[1] == ':')
+                  stripped_name += 2;
 
-		if (hash_find_entry (&keywords,
-				     stripped_name, strlen (stripped_name),
-				     &keyword_value)
-		    == 0)
-		  shapes = (const struct callshapes *) keyword_value;
+                if (hash_find_entry (&keywords,
+                                     stripped_name, strlen (stripped_name),
+                                     &keyword_value)
+                    == 0)
+                  shapes = (const struct callshapes *) keyword_value;
 
-		argparser = arglist_parser_alloc (mlp, shapes);
+                argparser = arglist_parser_alloc (mlp, shapes);
 
-		context_iter =
-		  flag_context_list_iterator (
-		    flag_context_list_table_lookup (
-		      flag_context_list_table,
-		      stripped_name, strlen (stripped_name)));
+                context_iter =
+                  flag_context_list_iterator (
+                    flag_context_list_table_lookup (
+                      flag_context_list_table,
+                      stripped_name, strlen (stripped_name)));
 
-		free (function_name);
-	      }
-	    else
-	      context_iter = null_context_list_iterator;
-	  }
-	else
-	  {
-	    /* These are the argument positions.  */
-	    if (argparser != NULL && inner.type == t_string)
-	      arglist_parser_remember (argparser, arg,
-				       string_of_word (&inner),
-				       inner_context,
-				       logical_file_name,
-				       inner.line_number_at_start,
-				       savable_comment);
-	  }
+                free (function_name);
+              }
+            else
+              context_iter = null_context_list_iterator;
+          }
+        else
+          {
+            /* These are the argument positions.  */
+            if (argparser != NULL && inner.type == t_string)
+              arglist_parser_remember (argparser, arg,
+                                       string_of_word (&inner),
+                                       inner_context,
+                                       logical_file_name,
+                                       inner.line_number_at_start,
+                                       savable_comment);
+          }
 
-	free_word (&inner);
+        free_word (&inner);
       }
   }
 }
@@ -956,16 +956,16 @@ read_command_list (int looking_for, flag_context_ty outer_context)
 
       terminator = read_command (looking_for, outer_context);
       if (terminator != t_separator)
-	return terminator;
+        return terminator;
     }
 }
 
 
 void
 extract_tcl (FILE *f,
-	     const char *real_filename, const char *logical_filename,
-	     flag_context_list_table_ty *flag_table,
-	     msgdomain_list_ty *mdlp)
+             const char *real_filename, const char *logical_filename,
+             flag_context_list_table_ty *flag_table,
+             msgdomain_list_ty *mdlp)
 {
   mlp = mdlp->item[0]->messages;
 
